# IXON CDK Ingress

The ixoncdkingress package provides the interface between the IXON Cloud and your Cloud Function.

Learn more about how to develop Cloud Functions on https://developer.ixon.cloud/docs/.
